```{include} ../../README.md

```

```{toctree}
---
maxdepth: 2
hidden:
---
tutorials/index.md
```

```{toctree}
---
maxdepth: 2
hidden:
---
how-to-guides/index.md
```

```{toctree}
---
maxdepth: 2
hidden:
---
reference/index.md
```
